@@ -1,5 +1,6 @@
 var NAVTREEINDEX5 =
 {
+"group__pw__session__manager.html#gacf65a96b2b6cb1f16af259bc667518bd":[8,5,4,137],
 "group__pw__session__manager.html#gacfc215ae22e6a99a5ff459f928d24daa":[8,5,4,35],
 "group__pw__session__manager.html#gad11c6d8d430ddbe887f200ea7b4c33d1":[8,5,4,187],
 "group__pw__session__manager.html#gad1df6ce293f28e872e608f95fbad9c7c":[8,5,4,108],
@@ -248,6 +249,5 @@ var NAVTREEINDEX5 =
 "group__spa__buffer.html#gae2090b468787d5a712acc82b1159fd30":[8,6,1,50],
 "group__spa__buffer.html#gae3317a3f21fe6eef3312dc4adde92c20":[8,6,1,70],
 "group__spa__buffer.html#gae3a8f97b5c95d6bc95bd2d4695b7dcf5":[8,6,1,54],
-"group__spa__buffer.html#gae56499a4188661fd69531560e4bd48bd":[8,6,1,16],
-"group__spa__buffer.html#gaeaf6a23eedc8287e462151c68cf392d8":[8,6,1,35]
+"group__spa__buffer.html#gae56499a4188661fd69531560e4bd48bd":[8,6,1,16]
 };
